@@ -459,10 +459,12 @@ vinagre_tube_handler_factory_handle_cb (TpConnection *connection,
 
   if (error != NULL)
     {
-      error_msg = g_strdup_printf
-          (_("Impossible to get the contact name: %s"), error->message);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
-          GTK_WINDOW (priv->window));
+      /* Translators: this is an error message when we fail to get the name of an empathy/telepathy buddy. %s will be replaced by the actual error message. */
+      error_msg = g_strdup_printf (_("Impossible to get the contact name: %s"),
+                                   error->message);
+      vinagre_utils_show_error (NULL,
+                                (const gchar *) error_msg,
+                                GTK_WINDOW (priv->window));
       g_free (error_msg);
       g_signal_emit (G_OBJECT (self), signals[DISCONNECTED], 0);
       return;
@@ -516,7 +518,7 @@ vinagre_tube_handler_factory_handle_cb (TpConnection *connection,
 
   dialog = gtk_message_dialog_new (GTK_WINDOW (priv->window),
       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION,
-      GTK_BUTTONS_OK_CANCEL, _("%s wants to share his desktop with you."),
+      GTK_BUTTONS_OK_CANCEL, _("%s wants to share their desktop with you."),
       alias);
 
   gtk_message_dialog_set_image (GTK_MESSAGE_DIALOG (dialog), image);
